==> qtjambi-datavisualization-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiDataVisualization/Q3DCamera_shell.h <==
#ifndef Q3DCAMERA_SHELL_H
#define Q3DCAMERA_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDataVisualization/q3dcamera.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDataVisualization/q3dobject.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qvector3d.h>
#include <QtJambi/RegistryAPI>


class Q3DCamera_shell : public QtDataVisualization::Q3DCamera, public QtJambiShellInterface
{
public:
    Q3DCamera_shell(QObject* parent0 = nullptr);
    ~Q3DCamera_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void copyValuesFrom(const QtDataVisualization::Q3DObject& source0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct Q3DCamera_access : public QtDataVisualization::Q3DCamera
{
    void __qt_copyValuesFrom_cref_QtDataVisualization_Q3DObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID source0);
};

#endif // Q3DCAMERA_SHELL_H

==> qtjambi-datavisualization-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiDataVisualization/Q3DCamera_shell.h <==
#ifndef Q3DCAMERA_SHELL_H
#define Q3DCAMERA_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDataVisualization/q3dcamera.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtDataVisualization/q3dobject.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qvectornd.h>
#include <QtJambi/RegistryAPI>


class Q3DCamera_shell : public Q3DCamera, public QtJambiShellInterface
{
public:
    Q3DCamera_shell(QObject* parent0 = nullptr);
    ~Q3DCamera_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void copyValuesFrom(const Q3DObject& source0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct Q3DCamera_access : public Q3DCamera
{
    void __qt_copyValuesFrom_cref_Q3DObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID source0);
};

#endif // Q3DCAMERA_SHELL_H
